@@ -92,11 +92,10 @@ class SimpleConsumer:
             getMessageResponse = self.scheduleInfoCache.get_or_create_message_client(
                 topicAndPartition=self.topicAndPartition).get_message(getMessageRequest)
         except Exception as e:
-            if isinstance(e, TTransportException):
+            if isinstance(e, TTransportException) or isinstance(e, ConnectionRefusedError):
                 if self.scheduleInfoCache and self.scheduleInfoCache.get_is_auto_location():
                     self.logger.warn("can't connect to the host directly, refresh scheduleInfo and retry using url. "
-                                     + "The exception message is :" + e.message +
-                                     ". Ignore this if not frequently.")
+                                     + "The exception message is : %s. Ignore this if not frequently.", e)
                     self.scheduleInfoCache.update_schedule_info_cache()
                     getMessageResponse = self.messageClient.get_message(getMessageRequest)
                 else:
